@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Flask Quorum
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Flask Quorum.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -57,6 +57,7 @@ from . import amqp
 from . import util
 from . import data
 from . import mail
+from . import info
 from . import route
 from . import model
 from . import legacy
@@ -127,6 +128,19 @@ ESCAPE_EXTENSIONS = (
 for which the autoescape mode will be enabled  by
 default as expected by the end developer """
 
+PLATFORM = "%s %d.%d.%d.%s %s" % (
+    sys.subversion[0] if hasattr(sys, "subversion") else "CPython",
+    sys.version_info[0],
+    sys.version_info[1],
+    sys.version_info[2],
+    sys.version_info[3],
+    sys.platform
+)
+""" Extra system information containing some of the details
+of the technical platform that is running the system, this
+string should be exposed carefully to avoid extra information
+from being exposed to outside agents """
+
 class Quorum(flask.Flask):
     """
     The top level application class that inherits from the
@@ -163,6 +177,15 @@ def call_run():
 def run(server = None, fallback = "base"):
     if not APP: raise exceptions.BaseError("Application not set or runnable")
 
+    APP.logger.info(
+        "Booting %s %s (flask %s) (%s) ..." % (
+            info.NAME,
+            info.VERSION,
+            flask.__version__,
+            PLATFORM
+        )
+    )
+
     server = config.conf("SERVER", server) or "base"
     runner = globals().get("run_" + server, None)
     runner_f = globals().get("run_" + fallback, None)
@@ -398,6 +421,19 @@ def load(
     config.confs("APPLICATION_ROOT", application_root)
     config.confs("PREFERRED_URL_SCHEME", url_scheme)
 
+    # retrieves some internal configuration value related with
+    # the way that the sessions are going to be handled
+    session_cookie_path = config.conf("SESSION_COOKIE_PATH", "/")
+    session_cookie_secure = config.conf("SESSION_COOKIE_SECURE", False, cast = bool)
+    session_refresh_request = config.conf("SESSION_REFRESH_EACH_REQUEST", False, cast = bool)
+
+    # re-sets a series of session related values according to quorum
+    # predefined structure, this effectively enables sessions on
+    # the client side to be handled in a predictable manner
+    config.confs("SESSION_COOKIE_PATH", session_cookie_path)
+    config.confs("SESSION_COOKIE_SECURE", session_cookie_secure)
+    config.confs("SESSION_REFRESH_EACH_REQUEST", session_refresh_request)
+
     # creates the proper values according to the currently provided
     # ones so that they match the ones that are expected
     name = name + "-" + instance if instance else name
