@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Flask Quorum
-# Copyright (c) 2008-2020 Hive Solutions Lda.
+# Copyright (c) 2008-2021 Hive Solutions Lda.
 #
 # This file is part of Hive Flask Quorum.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2021 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -82,7 +82,8 @@ number way of representing the same information """
 CASTERS = {
     list : lambda v: [y for y in itertools.chain(*[split_unescape(x, ",").split(",") for x in v])],
     bool : lambda v: v if isinstance(v, bool) else\
-        not v in ("", "0", "false", "False")
+        not v in ("", "0", "false", "False"),
+    dict : lambda v: json.loads(v) if legacy.is_string(v) else dict(v)
 }
 """ The map associating the various data types with a proper custom
 caster to be used for special data types (more complex) under some
@@ -238,13 +239,13 @@ def get_object(
     # retrieves the reference to the form objects currently
     # present in the request, note that in case a runtime
     # error occurs (eg: out of context) fails gracefully
-    try: form_s = flask.request.form_s
+    try: form_s = flask.request.form_s #@UndefinedVariable
     except RuntimeError: form_s = dict()
 
     # retrieves the reference to the arguments objects currently
     # present in the request, note that in case a runtime
     # error occurs (eg: out of context) fails gracefully
-    try: args_s = flask.request.args_s
+    try: args_s = flask.request.args_s #@UndefinedVariable
     except RuntimeError: args_s = dict()
 
     # uses all the values referencing data in the request to try
@@ -725,7 +726,7 @@ def set_locale():
     # normalizes the current locale string by converting the
     # last part of the locale string to an uppercase representation
     # and then re-joining the various components of it
-    values = flask.request.locale.split("_", 1)
+    values = flask.request.locale.split("_", 1) #@UndefinedVariable
     if len(values) > 1: values[1] = values[1].upper()
     locale_n = "_".join(values)
     locale_n = str(locale_n)
@@ -964,7 +965,7 @@ def to_locale(value, locale = None, default = None, fallback = True):
         ) for value in value
     ])
     has_context = common.base().has_context()
-    locale = locale or (flask.request.locale if has_context else None)
+    locale = locale or (flask.request.locale if has_context else None) #@UndefinedVariable
     if locale:
         bundle = common.base().get_bundle(locale) or {}
         result = bundle.get(value, None)
@@ -1418,6 +1419,16 @@ def verify_not_equal(first, second, message = None, code = None, exception = Non
         **kwargs
     )
 
+def verify_type(value, types, null = True, message = None, code = None, exception = None, **kwargs):
+    message = message or "Expected %s to have type %s" % (repr(value), repr(types))
+    return verify(
+        (null and value == None) or isinstance(value, types),
+        message = message,
+        code = code,
+        exception = exception,
+        **kwargs
+    )
+
 def verify_many(sequence, message = None, code = None, exception = None, **kwargs):
     for condition in sequence:
         verify(
